@@ -9,6 +9,7 @@ Provides init functions that are used to help set up the app.
 
 import argparse
 import datetime
+import ipaddress
 import logging
 import logging.config
 import os
@@ -17,6 +18,7 @@ import textwrap
 import time
 from pathlib import Path
 
+from lswifi import slog
 from lswifi.__version__ import __version__
 
 
@@ -169,6 +171,21 @@ def width(value):
     return width
 
 
+def syslog_ip(value):
+    """Validate user provided IP is actually an IP address"""
+    if value == "None":
+        return None
+    try:
+        servers = []
+        for ip in value.split(","):
+            ipaddress.ip_address(ip)
+            servers.append(ip)
+        slog.SYSLOG_SERVERS = servers
+        return servers  # return something so the arg is not None
+    except ValueError:
+        raise argparse.ArgumentTypeError("IP address {} is not valid".format(value))
+
+
 def setup_parser() -> argparse.ArgumentParser:
     """Sets up the parser for arguments passed into the module from the CLI.
 
@@ -517,6 +534,13 @@ def setup_parser() -> argparse.ArgumentParser:
         action="store_true",
         help="a special mode which watches for notification on a wireless interface such as connection and roaming events",
     )
+    parser.add_argument(
+        "--syslog",
+        metavar="<server IP>",
+        type=syslog_ip,
+        dest="syslog",
+        help="syslogs events from --watchevents to a remote syslog server",
+    )
     parser.add_argument(
         "--debug",
         action="store_const",
