@@ -20,6 +20,7 @@ from types import SimpleNamespace
 from typing import Union
 
 from lswifi import wlanapi as WLAN_API
+from lswifi.slog import message as syslog
 
 
 class TimerEx(object):
@@ -338,18 +339,19 @@ class Client(object):
                 now.now().astimezone().isoformat(timespec="milliseconds")
             )
             self.last_scan_time_utc = now.utcnow()
+            self.args = args
             self.get_bssid_args = SimpleNamespace(
                 get_current_ap=True,
                 raw=True,
                 event_watcher=True,
                 get_current_channel=False,
                 supported=False,
+                is_bytes_arg=self.args.bytes,
             )
             self.timeout_interval = 5.0
             self.client_handle = WLAN_API.WLAN.open_handle()
             # self.scan_timer = Timer(self.timeout_interval, self.scan_timeout)
             self.scan_timer = TimerEx(self.timeout_interval, self.scan_timeout)
-            self.args = args
             self.iface = iface
             self.mac = iface.mac
             # self.first_event = True
@@ -380,11 +382,11 @@ class Client(object):
                     "problem closing %s with result", self.client_handle, result
                 )
 
-    def get_bss_list(self, interface) -> Union[list, None]:
+    def get_bss_list(self, interface, bytes=False) -> Union[list, None]:
         if interface:
             try:
                 wireless_network_bss_list = WLAN_API.WLAN.get_wireless_network_bss_list(
-                    interface
+                    interface, is_bytes_arg=bytes
                 )
 
                 if len(wireless_network_bss_list) == 0:
@@ -432,7 +434,7 @@ class Client(object):
                     "profile_change",
                 ]:
                     if self.last_event == str(wlan_event).strip():
-                        if self.seconds_passed(self.oldepoch, 5):
+                        if self.seconds_passed(self.oldepoch, 2):
                             pass
                         else:
                             squelch = True
@@ -447,12 +449,14 @@ class Client(object):
                     "associated",
                     "authenticating",
                     "connected",
+                    "OneXNotificationTypeResultUpdate",
+                    "OneXNotificationTypeAuthRestarted",
                     "connection_complete",
                     "connection_start",
                     "roaming_start",
                     "roaming_end",
                 ]:
-                    self.data = self.get_bss_list(self.iface)
+                    self.data = self.get_bss_list(self.iface, bytes=self.args.bytes)
                     bssid_data = None
                     if self.data is not None:
                         for bss in self.data:
@@ -476,24 +480,34 @@ class Client(object):
                         ]:
                             extra = f", scan: ({len(self.data)} BSSIDs found)"
                         if not bssid:
-                            self.log.info(f"({self.mac}), event: ({wlan_event})")
+                            msg = f"({self.mac}), event: ({wlan_event})"
+                            self.log.info(msg)
+                            if self.args.syslog:
+                                syslog(msg, "INFO")
                         elif bssid == "00:00:00:00:00:00":
-                            self.log.info(
-                                f"({self.mac}), bssid: ({bssid}), event: ({wlan_event}){extra}"
-                            )
+                            msg = f"({self.mac}), bssid: ({bssid}), event: ({wlan_event}){extra}"
+                            self.log.info(msg)
+                            if self.args.syslog:
+                                syslog(msg, "INFO")
                         else:
-                            # print(bssid_data)ho
-                            self.log.info(
-                                f"({self.mac}), bssid: ({bssid}), freq: ({freq}), ssid: ({ssid}), rssi: ({rssi}), event: ({wlan_event}){extra}"
-                            )
+                            msg = f"({self.mac}), bssid: ({bssid}), freq: ({freq}), ssid: ({ssid}), rssi: ({rssi}), event: ({wlan_event}){extra}"
+                            self.log.info(msg)
+                            if self.args.syslog:
+                                syslog(msg, "INFO")
                 else:
                     if not squelch:
                         if bssid:
-                            self.log.info(
+                            msg = (
                                 f"({self.mac}), bssid: ({bssid}), event: ({wlan_event})"
                             )
+                            self.log.info(msg)
+                            if self.args.syslog:
+                                syslog(msg, "INFO")
                         else:
-                            self.log.info(f"({self.mac}), event: ({wlan_event})")
+                            msg = f"({self.mac}), event: ({wlan_event})"
+                            self.log.info(msg)
+                            if self.args.syslog:
+                                syslog(msg, "INFO")
 
             # if we're not watching for events and we want to return scan results
             if not self.args.event_watcher:
@@ -510,7 +524,9 @@ class Client(object):
                 # if the list is updated, grab the results
                 if str(wlan_event).strip() == "scan_list_refresh":
                     self.log.debug(f"({self.mac}), start get_bss_list...")
-                    self.data = self.get_bss_list(self.iface)
+                    self.data = self.get_bss_list(
+                        self.iface, bytes=self.args.bytes
+                    )
                     self.scan_finished = True
                     now = datetime.datetime
                     self.last_scan_time_epoch = now.utcnow().timestamp()
@@ -563,6 +579,6 @@ class Client(object):
             f"timeout interval ({self.timeout_interval} seconds) for {self.mac} exceeded..."
         )
         self.log.debug(f"({self.mac}), start get_bss_list...")
-        self.data = self.get_bss_list(self.iface)
+        self.data = self.get_bss_list(self.iface, bytes=self.args.bytes)
         self.log.debug(f"({self.mac}), finish get_bss_list...")
         self.scan_finished = True
